DROP TABLE webhelp;

-- WHF-260 Update database to save user email notifications
CREATE TABLE IF NOT EXISTS `email_notifications` (
  `emailNotificationId` int NOT NULL AUTO_INCREMENT,
  `userId` int NOT NULL,
  `userNotifications` BOOLEAN DEFAULT TRUE NOT NULL,
  `commentReply` BOOLEAN DEFAULT TRUE NOT NULL,
  `pageComment` BOOLEAN DEFAULT FALSE NOT NULL,
  PRIMARY KEY (`emailNotificationId`),
  UNIQUE KEY `userId` (`userId`),
  FOREIGN KEY (`userId`) REFERENCES `users`(`userId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1;

-- Update the notifications for the anonymous user putting all the values to false.
INSERT INTO `email_notifications` (userId, userNotifications, commentReply, pageComment) 
VALUES((SELECT userId FROM `users` WHERE `email`='anonymous@anonymous.com'), 0, 0, 0);

-- Update the notifications table for all the users except the anonymous user. Map the old notifications values 
-- (notifyReply to commentReply, notifyPage to pageComment) for each user and put the default values for the new ones.
INSERT INTO `email_notifications` (userId, commentReply, pageComment) SELECT userId, IF(notifyReply = 'yes', 1, 0), IF(notifyPage = 'yes', 1, 0) FROM `users` WHERE `email`<>'anonymous@anonymous.com' ORDER BY userId;

-- Drop the notify columns in the user table
ALTER TABLE `users` DROP COLUMN `notifyAll`;
ALTER TABLE `users` DROP COLUMN `notifyReply`;
ALTER TABLE `users` DROP COLUMN `notifyPage`;


-- User details table
CREATE TABLE IF NOT EXISTS `user_details` ( 
`userDetailsId` INT NOT NULL AUTO_INCREMENT , 
`userId` int NULL , 
`company` VARCHAR(256) NOT NULL, 
`creationDate` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP , 
`role` ENUM('ROLE_USER', 'ROLE_APPLICATION_ADMIN', 'ROLE_ANONYMOUS') NOT NULL DEFAULT 'ROLE_USER', 
`status` ENUM('created', 'validated', 'suspended') NOT NULL DEFAULT 'created',
`avatarName` VARCHAR(512), 
PRIMARY KEY (`userDetailsId`),
FOREIGN KEY (`userId`) REFERENCES `users`(`userId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;
INSERT INTO `user_details`(`userId`, `company`, `creationDate`, `status`, `role`) SELECT `userId`, `company`, `date`, `status`, IF(`users`.`email` = 'anonymous@anonymous.com', 'ROLE_ANONYMOUS', 'ROLE_USER') FROM `users`;
ALTER TABLE `users` DROP `company`, DROP `date`, DROP `status`, DROP `userName`;


-- Oauth credentials table
CREATE TABLE IF NOT EXISTS `oauth_credentials` ( 
`oauthCredentialsId` INT NOT NULL AUTO_INCREMENT , 
`userId` INT NOT NULL , 
`oauthUserId` VARCHAR(256) NOT NULL, 
`oauthProvider` VARCHAR(256) NOT NULL, 
PRIMARY KEY (`oauthCredentialsId`),
FOREIGN KEY (`userId`) REFERENCES `users`(`userId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;


-- Platform credentials table
CREATE TABLE IF NOT EXISTS `platform_credentials` ( 
`platformCredentialsId` INT NOT NULL AUTO_INCREMENT , 
`userId` INT NOT NULL , 
`password` VARCHAR(256) NOT NULL,
`tryLegacyPassword` BOOLEAN DEFAULT FALSE, 
PRIMARY KEY (`platformCredentialsId`),
FOREIGN KEY (`userId`) REFERENCES `users`(`userId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;
INSERT INTO `platform_credentials`(`userId`, `password`) SELECT `userId`, `password` FROM `users`;
UPDATE platform_credentials SET tryLegacyPassword=true;
ALTER TABLE `users` DROP COLUMN `password`;


-- Temporary users table
CREATE TABLE IF NOT EXISTS `temporary_users` ( 
`id` INT NOT NULL AUTO_INCREMENT , 
`name` VARCHAR(256) NOT NULL,
`oauthUserId` VARCHAR(256) NOT NULL, 
`oauthProvider` VARCHAR(256) NOT NULL, 
`token` VARCHAR(256) NOT NULL, 
`expiryDate` TIMESTAMP NOT NULL, 
PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;


-- Base URLs table
CREATE TABLE IF NOT EXISTS `base_urls` (
  `id` int NOT NULL AUTO_INCREMENT,
  `deploymentId` int NOT NULL,
  `url` varchar(256) NOT NULL,
  PRIMARY KEY (`id`),
  FOREIGN KEY (`deploymentId`) REFERENCES `deployments`(`deploymentId`),
  UNIQUE KEY `unique_url` (`deploymentId`, `url`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1;
-- Update the `base_url` table with the data from `deployments` table.
INSERT INTO `base_urls` (deploymentId, url) SELECT deploymentId, baseURL FROM `deployments`;
-- Drop the `baseURL` column in the deployments table
ALTER TABLE `deployments` DROP COLUMN `baseURL`;


-- Encryption key table
CREATE TABLE IF NOT EXISTS `encryption_key` (
  `id` int NOT NULL AUTO_INCREMENT,
  `value` varbinary(64) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1;