CREATE TABLE sites (
  siteId SERIAL NOT NULL,
  name varchar(255) NOT NULL,
  description varchar(255) DEFAULT NULL,
  commentsModerationPolicy varchar(255) NOT NULL DEFAULT 'all',
  allowAnonymousUser boolean DEFAULT false,
  logo varchar(511) DEFAULT NULL,
  PRIMARY KEY (siteId)
);

CREATE TABLE versions (
  versionId SERIAL NOT NULL,
  siteId int NOT NULL,
  version varchar(255) NOT NULL,
  minVisibleVersion varchar(255) DEFAULT NULL,
  installDate bigint NOT NULL,
  PRIMARY KEY (versionId),
  FOREIGN KEY (siteId) REFERENCES sites (siteId)
);

CREATE TABLE base_urls (
  baseUrlId SERIAL NOT NULL,
  versionId int NOT NULL,
  url varchar(511) NOT NULL,
  UNIQUE (versionId, url),
  PRIMARY KEY (baseUrlId),
  FOREIGN KEY (versionId) REFERENCES versions (versionId)
);

CREATE TABLE users (
  userId SERIAL NOT NULL,
  email varchar(320) NOT NULL,
  name varchar(511) NOT NULL,
  UNIQUE (email),
  PRIMARY KEY (userId)
);

CREATE TABLE user_details (
  userDetailsId SERIAL NOT NULL,
  userId int NOT NULL,
  company varchar(255) NOT NULL,
  creationDate timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  role varchar(255) NOT NULL DEFAULT 'ROLE_USER',
  status varchar(255) NOT NULL DEFAULT 'created',
  avatarName varchar(511) DEFAULT NULL,
  PRIMARY KEY (userDetailsId),
  UNIQUE (userId),
  FOREIGN KEY (userId) REFERENCES users (userId)
);

CREATE TABLE site_user_role (
  userId int NOT NULL,
  siteId int NOT NULL,
  role varchar(255) NOT NULL,
  PRIMARY KEY(userId, siteId),
  UNIQUE (userId, siteId, role),
  FOREIGN KEY (userId) REFERENCES users (userId),
  FOREIGN KEY (siteId) REFERENCES sites (siteId)
);

CREATE TABLE IF NOT EXISTS comments (
  commentId BIGSERIAL NOT NULL,
  content varchar NOT NULL,
  userId int NOT NULL,
  referedComment BIGINT DEFAULT NULL,
  commentState varchar(255) NOT NULL,
  page varchar(511) NOT NULL,
  versionId int NOT NULL,
  lastEditUserId int DEFAULT NULL,
  pageTitle varchar(255) DEFAULT NULL,
  creationDate bigint,
  PRIMARY KEY (commentId),
  FOREIGN KEY (userId) REFERENCES users (userId),
  FOREIGN KEY (referedComment) REFERENCES comments (commentId),
  FOREIGN KEY (versionId) REFERENCES versions (versionId),
  FOREIGN KEY (lastEditUserId) REFERENCES users (userId)
);

CREATE TABLE email_notifications (
  emailNotificationId SERIAL NOT NULL,
  userId int NOT NULL,
  userNotifications boolean NOT NULL DEFAULT true,
  commentReply boolean NOT NULL DEFAULT true,
  pageComment boolean NOT NULL DEFAULT false,
  PRIMARY KEY (emailNotificationId),
  FOREIGN KEY (userId) REFERENCES users (userId)
);

CREATE TABLE encryption_key (
  id SERIAL NOT NULL,
  value BYTEA NOT NULL,
  PRIMARY KEY (id)
);

CREATE TABLE oauth_credentials (
  oauthCredentialsId SERIAL NOT NULL,
  userId int NOT NULL,
  oauthUserId varchar(255) NOT NULL,
  oauthProvider varchar(255) NOT NULL,
  PRIMARY KEY (oauthCredentialsId),
  FOREIGN KEY (userId) REFERENCES users (userId)
);

CREATE TABLE platform_credentials (
  platformCredentialsId SERIAL NOT NULL,
  userId int NOT NULL,
  password varchar(255) NOT NULL,
  tryLegacyPassword BOOLEAN DEFAULT FALSE,
  PRIMARY KEY (platformCredentialsId),
  UNIQUE (userId),
  FOREIGN KEY (userId) REFERENCES users (userId)
);

CREATE TABLE temporary_users (
  id SERIAL NOT NULL,
  name varchar(255) NOT NULL,
  oauthUserId varchar(255) NOT NULL,
  oauthProvider varchar(255) NOT NULL,
  token varchar(255) NOT NULL,
  expiryDate timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (id)
);

INSERT INTO users (userId, email, name) VALUES (1, 'anonymous@anonymous.com', 'Anonymous');
INSERT INTO email_notifications(emailNotificationId, userId, userNotifications, commentReply, pageComment)
VALUES (1, 1, false, false, false);
INSERT INTO platform_credentials (platformCredentialsId, userId, password) VALUES (1, 1, '5ea722eade385e12481779133307e64c');
INSERT INTO user_details (userDetailsId, userId, company, creationDate, role, status, avatarName) VALUES (1, 1, 'NA', '2011-12-31 20:00:00', 'ROLE_ANONYMOUS', 'validated', NULL);

ALTER SEQUENCE users_userid_seq RESTART WITH 2;
ALTER SEQUENCE user_details_userdetailsid_seq RESTART WITH 2;
ALTER SEQUENCE email_notifications_emailnotificationid_seq RESTART WITH 2;
ALTER SEQUENCE platform_credentials_platformcredentialsid_seq RESTART WITH 2;
